==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Visualizzazione grafica</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translation>Colori</translation>
    </message>
</context>
<context>
    <name>Colors</name>
    <message>
        <source>Colors</source>
        <translation type="obsolete">Colori</translation>
    </message>
    <message>
        <source>Graphics View</source>
        <translatorcomment>--exact match--
--file: DefaultNavigation_it.ts--
Visualizzazione grafica</translatorcomment>
        <translation type="obsolete">Visualizzazione grafica</translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation>Visualizzazione grafica</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translation>Sfondo:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation>Cursore</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Crosshairs:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Reticolo:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Inactive crosshairs:</source>
        <translation>Reticolo inattivo:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation>Origine</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Relative zero:</source>
        <translation>Zero relativo:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation>Griglia</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Meta grid:</source>
        <translation>Meta griglia:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation>Selezione</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation>Colore primario per la selezione:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation>Usa colore secondario di selezione</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation>Colore secondario di selezione:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation>Punti di riferimento:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation>Punti di riferimento secondario:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation>Confine finestra di selezione:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation>Finestra di selezione:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation>Finestra di selezione interseca:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Snap Tools</source>
        <translation>Strumenti snap</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation>Etichetta aggancia:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation>Strumenti info</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation>Misure ed etichette:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation>Strumenti di disegno</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation>Forme ausiliaria:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation>Strumenti zoom</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation>Confine finestra di selezione:</translation>
    </message>
    <message>
        <source>Inactive Crosshairs:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Reticolo inattivo:</translation>
    </message>
    <message>
        <location line="-562"/>
        <source>Origin:</source>
        <translatorcomment>--exact match--
--file: qgis_it.ts--
Origine:</translatorcomment>
        <translation>Origine:</translation>
    </message>
    <message>
        <source>Relative Zero:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Zero relativo:</translation>
    </message>
    <message>
        <source>Reference Point:</source>
        <translation type="obsolete">Punto di riferimento:</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Grid:</source>
        <translatorcomment>--ignored colon--
--file: it.po--
Meta griglia:
&amp;Meta griglia:</translatorcomment>
        <translation>Griglia:</translation>
    </message>
    <message>
        <source>Meta Grid:</source>
        <translation type="obsolete">Meta griglia:</translation>
    </message>
    <message>
        <source>Zoom Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Finestra di zoom:</translation>
    </message>
    <message>
        <source>Selection:</source>
        <translatorcomment>--ignored colon--
--file: it3.po--</translatorcomment>
        <translation type="obsolete">Selezione:</translation>
    </message>
    <message>
        <source>Selection Box Border:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Confine finestra di selezione:</translation>
    </message>
    <message>
        <source>Selection Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Finestra di selezione:</translation>
    </message>
    <message>
        <source>Cross Selection Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Finestra di selezione interseca:</translation>
    </message>
    <message>
        <source>Auxiliary Shapes:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Forme ausiliaria:</translation>
    </message>
    <message>
        <source>Info Label Background:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Sfondo di etichetta informazioni:</translation>
    </message>
    <message>
        <source>Info Label Font:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Testo di etichetta informazioni:</translation>
    </message>
    <message>
        <source>Measurement Tools:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Strumenti di misurazione:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Visualizzazione grafica</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translation>Colori</translation>
    </message>
</context>
<context>
    <name>Colors</name>
    <message>
        <source>Colors</source>
        <translation type="obsolete">Colori</translation>
    </message>
    <message>
        <source>Graphics View</source>
        <translatorcomment>--exact match--
--file: DefaultNavigation_it.ts--
Visualizzazione grafica</translatorcomment>
        <translation type="obsolete">Visualizzazione grafica</translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation>Visualizzazione grafica</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translation>Sfondo:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation>Cursore</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Crosshairs:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Reticolo:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Inactive crosshairs:</source>
        <translation>Reticolo inattivo:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation>Origine</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Relative zero:</source>
        <translation>Zero relativo:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation>Griglia</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Meta grid:</source>
        <translation>Meta griglia:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation>Selezione</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation>Colore primario per la selezione:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation>Usa colore secondario di selezione</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation>Colore secondario di selezione:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation>Punti di riferimento:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation>Punti di riferimento secondario:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation>Confine finestra di selezione:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation>Finestra di selezione:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation>Finestra di selezione interseca:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Start points:</source>
        <translation>Punti di partenza:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End points:</source>
        <translation>Punti finali:</translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Snap Tools</source>
        <translation>Strumenti snap</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation>Etichetta aggancia:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation>Strumenti info</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation>Misure ed etichette:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation>Strumenti di disegno</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation>Forme ausiliaria:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation>Strumenti zoom</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation>Confine finestra di selezione:</translation>
    </message>
    <message>
        <source>Inactive Crosshairs:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Reticolo inattivo:</translation>
    </message>
    <message>
        <location line="-616"/>
        <source>Origin:</source>
        <translatorcomment>--exact match--
--file: qgis_it.ts--
Origine:</translatorcomment>
        <translation>Origine:</translation>
    </message>
    <message>
        <source>Relative Zero:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Zero relativo:</translation>
    </message>
    <message>
        <source>Reference Point:</source>
        <translation type="obsolete">Punto di riferimento:</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Grid:</source>
        <translatorcomment>--ignored colon--
--file: it.po--
Meta griglia:
&amp;Meta griglia:</translatorcomment>
        <translation>Griglia:</translation>
    </message>
    <message>
        <source>Meta Grid:</source>
        <translation type="obsolete">Meta griglia:</translation>
    </message>
    <message>
        <source>Zoom Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Finestra di zoom:</translation>
    </message>
    <message>
        <source>Selection:</source>
        <translatorcomment>--ignored colon--
--file: it3.po--</translatorcomment>
        <translation type="obsolete">Selezione:</translation>
    </message>
    <message>
        <source>Selection Box Border:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Confine finestra di selezione:</translation>
    </message>
    <message>
        <source>Selection Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Finestra di selezione:</translation>
    </message>
    <message>
        <source>Cross Selection Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Finestra di selezione interseca:</translation>
    </message>
    <message>
        <source>Auxiliary Shapes:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Forme ausiliaria:</translation>
    </message>
    <message>
        <source>Info Label Background:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Sfondo di etichetta informazioni:</translation>
    </message>
    <message>
        <source>Info Label Font:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Testo di etichetta informazioni:</translation>
    </message>
    <message>
        <source>Measurement Tools:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Strumenti di misurazione:</translation>
    </message>
</context>
</TS>
